@@ -16,6 +16,7 @@
 #include <DiscoverBackendsFactory.h>
 #include <KConfigGroup>
 #include <KLocalizedString>
+#include <KOSRelease>
 #include <KSharedConfig>
 #include <QCoreApplication>
 #include <QIcon>
@@ -95,8 +96,8 @@ void ResourcesModel::init(bool load)
         QMetaObject::invokeMethod(this, "registerAllBackends", Qt::QueuedConnection);
 
     m_updateAction = new DiscoverAction(this);
-    m_updateAction->setIcon(QIcon::fromTheme(QStringLiteral("system-software-update")));
-    m_updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
+    m_updateAction->setIconName(QStringLiteral("system-software-update"));
+    m_updateAction->setText(i18n("Refresh"));
     connect(this, &ResourcesModel::fetchingChanged, m_updateAction, [this](bool fetching) {
         m_updateAction->setEnabled(!fetching);
         m_fetchingUpdatesProgress.reevaluate();
@@ -417,3 +418,8 @@ QString ResourcesModel::applicationSourceName() const
     KConfigGroup settings(KSharedConfig::openConfig(), "ResourcesModel");
     return settings.readEntry<QString>("currentApplicationBackend", QStringLiteral("packagekit-backend"));
 }
+
+QUrl ResourcesModel::distroBugReportUrl()
+{
+    return KOSRelease().bugReportUrl();
+}
